@@ -1,10 +1,12 @@
 """Generate nice error messages."""
 
 from pathlib import Path
+from pprint import pformat
 
-from beartype.typing import Any, List
+from beartype import beartype
+from beartype.typing import Any
 
-from .differ import DiffResult
+from .differ import DiffResults
 
 
 class NoCacheError(FileNotFoundError):
@@ -16,7 +18,7 @@ class NoCacheError(FileNotFoundError):
 class RichAssertionError(AssertionError):
     """Custom AssertionError with additional `error_info`."""
 
-    def __init__(self, *args, error_info: Any = None) -> None:
+    def __init__(self, *args: Any, error_info: Any = None) -> None:
         """Store the error_info for later access."""  # noqa: DAR101
         super().__init__(*args)
         self.error_info = error_info
@@ -24,7 +26,7 @@ class RichAssertionError(AssertionError):
     @classmethod
     def create_message(
         cls, test_data: Any, cached_data: Any, path_cache_file: Path,
-        diff_results: List[DiffResult],
+        diff_results: DiffResults,
     ) -> str:
         """Create the error message.
 
@@ -38,8 +40,13 @@ class RichAssertionError(AssertionError):
             str: pleasant error message
 
         """
-        # PLANNED: Cap length of error message. There might be a library that can help with that
-        return f"""For test data: {test_data}
-Found differences with: {path_cache_file}
-Differences: {diff_results}
-"""
+        @beartype
+        def fmt_line(prefix: str, data: Any) -> str:
+            indented_data = ('\n' + ' ' * len(prefix)).join(pformat(data).split('\n'))
+            return f'{prefix}{indented_data}'
+
+        data_prefix = '> For test data: '
+        diff_prefix = '> Differences: '
+        line_data = fmt_line(data_prefix, test_data)
+        line_diff = fmt_line(diff_prefix, diff_results.to_dict())
+        return f'\n{line_data}\n> Found differences with: {path_cache_file}\n{line_diff}\n'
